#
# spec file for package libpagemaker
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libpagemaker-0_0-0
Name:           libpagemaker
Version:        0.0.4
Release:        lp152.3.7
Summary:        A library to import Adobe PageMaker documents
License:        MPL-2.0
Group:          Productivity/Publishing/Word
Url:            http://wiki.documentfoundation.org/DLP/Libraries/libpagemaker
Source0:        http://dev-www.libreoffice.org/src/%{name}/%{name}-%{version}.tar.xz
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(librevenge-0.0)
BuildRequires:  pkgconfig(librevenge-generators-0.0)
BuildRequires:  pkgconfig(librevenge-stream-0.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif

%description
libpagemaker is library providing ability to interpret and import
Adobe PageMaker documents into various applications.

%package -n %{libname}
Summary:        A library to import Adobe PageMaker documents
Group:          System/Libraries

%description -n %{libname}
libpagemaker is library providing ability to interpret and import
Adobe PageMaker documents into various applications.

%package devel
Summary:        Files for Developing with libpagemaker
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
libpagemaker is library providing ability to interpret and import
Adobe PageMaker documents into various applications.

This package contains the libpagemaker development files.

%package devel-doc
Summary:        Documentation for the libpagemaker API
Group:          Documentation/HTML
BuildArch:      noarch

%description devel-doc
This package contains documentation for the libpagemaker API.

%package tools
Summary:        Tools to transform Adobe PageMaker documents into other formats
Group:          Productivity/Publishing/Word

%description tools
Tools to transform Adobe PageMaker documents into other formats.
Currently supported: SVG, raw.

%prep
%setup -q

%build
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
%configure \
    --disable-silent-rules \
    --disable-werror \
    --disable-static \
    --docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# documentation
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -p AUTHORS COPYING ChangeLog %{buildroot}%{_docdir}/%{name}

%fdupes -s %{buildroot}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc NEWS COPYING ChangeLog
%{_libdir}/*.so.*

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/libpagemaker*.pc
%{_includedir}/libpagemaker-*

%files devel-doc
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/html

%files tools
%{_bindir}/*
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/[A-Z]*

%changelog
* Tue Jan  9 2018 jengelh@inai.de
- Cure linguistic problem in descriptions.
* Mon Jan  8 2018 tchvatal@suse.com
- Update to 0.0.4:
  * Add a command line tool for conversion to plain text, called pmd2text.
  * Require C++11 for build.
  * Drop outdated MSVC project files.
  * Fix parsing of page dimensions and shape coordinates in Mac documents.
    That makes the output at least somewhat useful, but more work is needed
    to handle big endian files properly.
  * Fix parsing of color tint in Mac documents. (tdf#109126)
  * Fix parsing of text formatting attributes in Mac documents.
  * Properly handle all caps and small caps.
  * Parse more text formatting attributes.
  * Parse more paragraph attributes.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Aug  1 2016 tchvatal@suse.com
- Disable sle11 support code
* Wed Mar 23 2016 tchvatal@suse.com
- Version update to 0.0.3:
  * remove upstreamed patch libpagemaker-0.0.2-no_undefined.patch
  * Make --help output of conversion tools help2man-friendly.
  * Read big endian (Mac) files (tdf#91419).
  * Other small fixes and improvements.
* Fri Nov 28 2014 fstrba@suse.com
- Initial package based on upstream libpagemaker 0.0.2
- Add patch: libpagemaker-0.0.2-no_undefined.patch
  * fix a typo (-no-undefines -> -no-undefined) in Makefile
